@@ -32,7 +32,7 @@
     "Romaneste",
     "Magyar",
     "Catal",
-    "a", // Russian
+    "", // Russian
   },
 */
 
@@ -56,7 +56,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    " ",
 #endif
   },
 
@@ -77,7 +77,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "       ",
 #endif
   },
 
@@ -98,7 +98,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "   ",
 #endif
   },
 
@@ -120,7 +120,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "  -     ",
 #endif
   },
 
@@ -141,7 +141,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "  RC5",
 #endif
   },
 
@@ -162,7 +162,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "  RC5 (  )",
 #endif
   },
 
@@ -183,7 +183,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "  RCMM",
 #endif
   },
 
@@ -204,7 +204,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "  RCMM (  )",
 #endif
   },
 
@@ -225,7 +225,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "   ",
 #endif
   },
 
@@ -246,7 +246,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "   ",
 #endif
   },
 
@@ -267,7 +267,7 @@ const tI18nPhrase remotePhrases[] = {
     "",
     "",
 #if VDRVERSNUM >= 10302
-    "",
+    "%s: %s",
 #endif
   },
 
